<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>Window</name>
    <message>
        <location filename="../Window.js" line="+108"/>
        <source>&amp;Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Window Tools</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
